# 20220523_allsky_std


Standard production (no tuning) for declinations 6676 and min_2924


## Paths

```
/fefs/aswg/data/mc/IRF/AllSky/20220523_allsky_std/TestingDataset/{dec}/{node}/

/fefs/aswg/data/models/AllSky/20220523_allsky_std/{dec}/
```
